"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_custom_attributes(UserPoolId=None, CustomAttributes=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to add custom attributes.
            
    :type UserPoolId: string
    :param CustomAttributes: [REQUIRED]
            An array of custom attributes, such as Mutable and Name.
            (dict) --Contains information about the schema attribute.
            Name (string) --A schema attribute of the name type.
            AttributeDataType (string) --The attribute data type.
            DeveloperOnlyAttribute (boolean) --Specifies whether the attribute type is developer only.
            Mutable (boolean) --Specifies whether the attribute can be changed once it has been created.
            Required (boolean) --Specifies whether a user pool attribute is required. If the attribute is required and the user does not provide a value, registration or sign-in will fail.
            NumberAttributeConstraints (dict) --Specifies the constraints for an attribute of the number type.
            MinValue (string) --The minimum value of an attribute that is of the number data type.
            MaxValue (string) --The maximum value of an attribute that is of the number data type.
            StringAttributeConstraints (dict) --Specifies the constraints for an attribute of the string type.
            MinLength (string) --The minimum length of an attribute value of the string type.
            MaxLength (string) --The maximum length of an attribute value of the string type.
            
            
    :type CustomAttributes: list
    """
    pass

def admin_confirm_sign_up(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for which you want to confirm user registration.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name for which you want to confirm user registration.
            
    :type Username: string
    """
    pass

def admin_create_user(UserPoolId=None, Username=None, UserAttributes=None, ValidationData=None, TemporaryPassword=None, ForceAliasCreation=None, MessageAction=None, DesiredDeliveryMediums=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where the user will be created.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The username for the user. Must be unique within the user pool. Must be a UTF-8 string between 1 and 128 characters. After the user is created, the username cannot be changed.
            
    :type Username: string
    :param UserAttributes: An array of name-value pairs that contain user attributes and attribute values to be set for the user to be created. You can create a user without specifying any attributes other than Username. However, any attributes that you specify as required (in CreateUserPool or in the Attributes tab of the console) must be supplied either by you (in your call to AdminCreateUser) or by the user (when he or she signs up in response to your welcome message).
            To send a message inviting the user to sign up, you must specify the user's email address or phone number. This can be done in your call to AdminCreateUser or in the Users tab of the Amazon Cognito console for managing your user pools.
            In your call to AdminCreateUser, you can set the email_verified attribute to True, and you can set the phone_number_verified attribute to True. (You cannot do this by calling other operations such as AdminUpdateUserAttributes.)
            email : The email address of the user to whom the message that contains the code and username will be sent. Required if the email_verified attribute is set to True, or if 'EMAIL' is specified in the DesiredDeliveryMediums parameter.
            phone_number : The phone number of the user to whom the message that contains the code and username will be sent. Required if the phone_number_verified attribute is set to True, or if 'SMS' is specified in the DesiredDeliveryMediums parameter.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type UserAttributes: list
    :param ValidationData: The user's validation data. This is an array of name-value pairs that contain user attributes and attribute values that you can use for custom validation, such as restricting the types of user accounts that can be registered. For example, you might choose to allow or disallow user sign-up based on the user's domain.
            To configure custom validation, you must create a Pre Sign-up Lambda trigger for the user pool as described in the Amazon Cognito Developer Guide. The Lambda trigger receives the validation data and uses it in the validation process.
            The user's validation data is not persisted.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type ValidationData: list
    :param TemporaryPassword: The user's temporary password. This password must conform to the password policy that you specified when you created the user pool.
            The temporary password is valid only once. To complete the Admin Create User flow, the user must enter the temporary password in the sign-in page along with a new password to be used in all future sign-ins.
            This parameter is not required. If you do not specify a value, Amazon Cognito generates one for you.
            The temporary password can only be used until the user account expiration limit that you specified when you created the user pool. To reset the account after that time limit, you must call AdminCreateUser again, specifying 'RESEND' for the MessageAction parameter.
            
    :type TemporaryPassword: string
    :param ForceAliasCreation: This parameter is only used if the phone_number_verified or email_verified attribute is set to True. Otherwise, it is ignored.
            If this parameter is set to True and the phone number or email address specified in the UserAttributes parameter already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user. The previous user will no longer be able to log in using that alias.
            If this parameter is set to False, the API throws an AliasExistsException error if the alias already exists. The default value is False.
            
    :type ForceAliasCreation: boolean
    :param MessageAction: Set to 'RESEND' to resend the invitation message to a user that already exists and reset the expiration limit on the user's account. Set to 'SUPPRESS' to suppress sending the message. Only one value can be specified.
    :type MessageAction: string
    :param DesiredDeliveryMediums: Specify 'EMAIL' if email will be used to send the welcome message. Specify 'SMS' if the phone number will be used. The default value is 'SMS'. More than one value can be specified.
            (string) --
            
    :type DesiredDeliveryMediums: list
    """
    pass

def admin_delete_user(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to delete the user.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user you wish to delete.
            
    :type Username: string
    """
    pass

def admin_delete_user_attributes(UserPoolId=None, Username=None, UserAttributeNames=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to delete user attributes.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user from which you would like to delete attributes.
            
    :type Username: string
    :param UserAttributeNames: [REQUIRED]
            An array of strings representing the user attribute names you wish to delete.
            (string) --
            
    :type UserAttributeNames: list
    """
    pass

def admin_disable_user(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to disable the user.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user you wish to disable.
            
    :type Username: string
    """
    pass

def admin_enable_user(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to enable the user.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user you wish to ebable.
            
    :type Username: string
    """
    pass

def admin_forget_device(UserPoolId=None, Username=None, DeviceKey=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name.
            
    :type Username: string
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    """
    pass

def admin_get_device(DeviceKey=None, UserPoolId=None, Username=None):
    """
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    :param UserPoolId: [REQUIRED]
            The user pool ID.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name.
            
    :type Username: string
    """
    pass

def admin_get_user(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to get information about the user.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user you wish to retrieve.
            
    :type Username: string
    """
    pass

def admin_initiate_auth(UserPoolId=None, ClientId=None, AuthFlow=None, AuthParameters=None, ClientMetadata=None):
    """
    :param UserPoolId: [REQUIRED]
            The ID of the Amazon Cognito user pool.
            
    :type UserPoolId: string
    :param ClientId: [REQUIRED]
            The client app ID.
            
    :type ClientId: string
    :param AuthFlow: [REQUIRED]
            The authentication flow.
            
    :type AuthFlow: string
    :param AuthParameters: The authentication parameters.
            (string) --
            (string) --
            
    :type AuthParameters: dict
    :param ClientMetadata: The client app metadata.
            (string) --
            (string) --
            
    :type ClientMetadata: dict
    """
    pass

def admin_list_devices(UserPoolId=None, Username=None, Limit=None, PaginationToken=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name.
            
    :type Username: string
    :param Limit: The limit of the devices request.
    :type Limit: integer
    :param PaginationToken: The pagination token.
    :type PaginationToken: string
    """
    pass

def admin_reset_user_password(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to reset the user's password.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user whose password you wish to reset.
            
    :type Username: string
    """
    pass

def admin_respond_to_auth_challenge(UserPoolId=None, ClientId=None, ChallengeName=None, ChallengeResponses=None, Session=None):
    """
    :param UserPoolId: [REQUIRED]
            The ID of the Amazon Cognito user pool.
            
    :type UserPoolId: string
    :param ClientId: [REQUIRED]
            The client ID.
            
    :type ClientId: string
    :param ChallengeName: [REQUIRED]
            The name of the challenge.
            
    :type ChallengeName: string
    :param ChallengeResponses: The challenge response.
            (string) --
            (string) --
            
    :type ChallengeResponses: dict
    :param Session: The session.
    :type Session: string
    """
    pass

def admin_set_user_settings(UserPoolId=None, Username=None, MFAOptions=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to set the user's settings, such as MFA options.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user for whom you wish to set user settings.
            
    :type Username: string
    :param MFAOptions: [REQUIRED]
            Specifies the options for MFA (e.g., email or phone number).
            (dict) --Specifies the different settings for multi-factor authentication (MFA).
            DeliveryMedium (string) --The delivery medium (email message or SMS message) to send the MFA code.
            AttributeName (string) --The attribute name of the MFA option type.
            
            
    :type MFAOptions: list
    """
    pass

def admin_update_device_status(UserPoolId=None, Username=None, DeviceKey=None, DeviceRememberedStatus=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name.
            
    :type Username: string
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    :param DeviceRememberedStatus: The status indicating whether a device has been remembered or not.
    :type DeviceRememberedStatus: string
    """
    pass

def admin_update_user_attributes(UserPoolId=None, Username=None, UserAttributes=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to update user attributes.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name of the user for whom you want to update user attributes.
            
    :type Username: string
    :param UserAttributes: [REQUIRED]
            An array of name-value pairs representing user attributes.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type UserAttributes: list
    """
    pass

def admin_user_global_sign_out(UserPoolId=None, Username=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID.
            
    :type UserPoolId: string
    :param Username: [REQUIRED]
            The user name.
            
    :type Username: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def change_password(PreviousPassword=None, ProposedPassword=None, AccessToken=None):
    """
    :param PreviousPassword: [REQUIRED]
            The old password in the change password request.
            
    :type PreviousPassword: string
    :param ProposedPassword: [REQUIRED]
            The new password in the change password request.
            
    :type ProposedPassword: string
    :param AccessToken: The access token in the change password request.
    :type AccessToken: string
    """
    pass

def confirm_device(AccessToken=None, DeviceKey=None, DeviceSecretVerifierConfig=None, DeviceName=None):
    """
    :param AccessToken: [REQUIRED]
            The access token.
            
    :type AccessToken: string
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    :param DeviceSecretVerifierConfig: The configuration of the device secret verifier.
            PasswordVerifier (string) --The password verifier.
            Salt (string) --The salt.
            
    :type DeviceSecretVerifierConfig: dict
    :param DeviceName: The device name.
    :type DeviceName: string
    """
    pass

def confirm_forgot_password(ClientId=None, SecretHash=None, Username=None, ConfirmationCode=None, Password=None):
    """
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param SecretHash: A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
    :type SecretHash: string
    :param Username: [REQUIRED]
            The user name of the user for whom you want to enter a code to retrieve a forgotten password.
            
    :type Username: string
    :param ConfirmationCode: [REQUIRED]
            The confirmation code sent by a user's request to retrieve a forgotten password.
            
    :type ConfirmationCode: string
    :param Password: [REQUIRED]
            The password sent by sent by a user's request to retrieve a forgotten password.
            
    :type Password: string
    """
    pass

def confirm_sign_up(ClientId=None, SecretHash=None, Username=None, ConfirmationCode=None, ForceAliasCreation=None):
    """
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param SecretHash: A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
    :type SecretHash: string
    :param Username: [REQUIRED]
            The user name of the user whose registration you wish to confirm.
            
    :type Username: string
    :param ConfirmationCode: [REQUIRED]
            The confirmation code sent by a user's request to confirm registration.
            
    :type ConfirmationCode: string
    :param ForceAliasCreation: Boolean to be specified to force user confirmation irrespective of existing alias. By default set to False. If this parameter is set to True and the phone number/email used for sign up confirmation already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user being confirmed. If set to False, the API will throw an AliasExistsException error.
    :type ForceAliasCreation: boolean
    """
    pass

def create_user_import_job(JobName=None, UserPoolId=None, CloudWatchLogsRoleArn=None):
    """
    :param JobName: [REQUIRED]
            The job name for the user import job.
            
    :type JobName: string
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are being imported into.
            
    :type UserPoolId: string
    :param CloudWatchLogsRoleArn: [REQUIRED]
            The role ARN for the Amazon CloudWatch Logging role for the user import job.
            
    :type CloudWatchLogsRoleArn: string
    """
    pass

def create_user_pool(PoolName=None, Policies=None, LambdaConfig=None, AutoVerifiedAttributes=None, AliasAttributes=None, SmsVerificationMessage=None, EmailVerificationMessage=None, EmailVerificationSubject=None, SmsAuthenticationMessage=None, MfaConfiguration=None, DeviceConfiguration=None, EmailConfiguration=None, SmsConfiguration=None, AdminCreateUserConfig=None):
    """
    :param PoolName: [REQUIRED]
            A string used to name the user pool.
            
    :type PoolName: string
    :param Policies: The policies associated with the new user pool.
            PasswordPolicy (dict) --A container with information about the user pool password policy.
            MinimumLength (integer) --The minimum length of the password policy that you have set. Cannot be less than 6.
            RequireUppercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.
            RequireLowercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.
            RequireNumbers (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one number in their password.
            RequireSymbols (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.
            
            
    :type Policies: dict
    :param LambdaConfig: The Lambda trigger configuration information for the new user pool.
            PreSignUp (string) --A pre-registration AWS Lambda trigger.
            CustomMessage (string) --A custom Message AWS Lambda trigger.
            PostConfirmation (string) --A post-confirmation AWS Lambda trigger.
            PreAuthentication (string) --A pre-authentication AWS Lambda trigger.
            PostAuthentication (string) --A post-authentication AWS Lambda trigger.
            DefineAuthChallenge (string) --Defines the authentication challenge.
            CreateAuthChallenge (string) --Creates an authentication challenge.
            VerifyAuthChallengeResponse (string) --Verifies the authentication challenge response.
            
    :type LambdaConfig: dict
    :param AutoVerifiedAttributes: The attributes to be auto-verified. Possible values: email , phone_number .
            (string) --
            
    :type AutoVerifiedAttributes: list
    :param AliasAttributes: Attributes supported as an alias for this user pool. Possible values: phone_number , email , or preferred_username .
            (string) --
            
    :type AliasAttributes: list
    :param SmsVerificationMessage: A string representing the SMS verification message.
    :type SmsVerificationMessage: string
    :param EmailVerificationMessage: A string representing the email verification message.
    :type EmailVerificationMessage: string
    :param EmailVerificationSubject: A string representing the email verification subject.
    :type EmailVerificationSubject: string
    :param SmsAuthenticationMessage: A string representing the SMS authentication message.
    :type SmsAuthenticationMessage: string
    :param MfaConfiguration: Specifies MFA configuration details.
    :type MfaConfiguration: string
    :param DeviceConfiguration: The device configuration.
            ChallengeRequiredOnNewDevice (boolean) --Indicates whether a challenge is required on a new device. Only applicable to a new device.
            DeviceOnlyRememberedOnUserPrompt (boolean) --If true, a device is only remembered on user prompt.
            
    :type DeviceConfiguration: dict
    :param EmailConfiguration: The email configuration.
            SourceArn (string) --The Amazon Resource Name (ARN) of the email source.
            ReplyToEmailAddress (string) --The REPLY-TO email address.
            
    :type EmailConfiguration: dict
    :param SmsConfiguration: The SMS configuration.
            SnsCallerArn (string) --The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) caller.
            ExternalId (string) --The external ID.
            
    :type SmsConfiguration: dict
    :param AdminCreateUserConfig: The configuration for AdminCreateUser requests.
            AllowAdminCreateUserOnly (boolean) --Set to True if only the administrator is allowed to create user profiles. Set to False if users can sign themselves up via an app.
            UnusedAccountValidityDays (integer) --The user account expiration limit, in days, after which the account is no longer usable. To reset the account after that time limit, you must call AdminCreateUser again, specifying 'RESEND' for the MessageAction parameter.
            InviteMessageTemplate (dict) --The message template to be used for the welcome message to new users.
            SMSMessage (string) --The message template for SMS messages.
            EmailMessage (string) --The message template for email messages.
            EmailSubject (string) --The subject line for email messages.
            
            
    :type AdminCreateUserConfig: dict
    """
    pass

def create_user_pool_client(UserPoolId=None, ClientName=None, GenerateSecret=None, RefreshTokenValidity=None, ReadAttributes=None, WriteAttributes=None, ExplicitAuthFlows=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to create a user pool client.
            
    :type UserPoolId: string
    :param ClientName: [REQUIRED]
            The client name for the user pool client you would like to create.
            
    :type ClientName: string
    :param GenerateSecret: Boolean to specify whether you want to generate a secret for the user pool client being created.
    :type GenerateSecret: boolean
    :param RefreshTokenValidity: Refreshes the token validity.
    :type RefreshTokenValidity: integer
    :param ReadAttributes: The read attributes.
            (string) --
            
    :type ReadAttributes: list
    :param WriteAttributes: The write attributes.
            (string) --
            
    :type WriteAttributes: list
    :param ExplicitAuthFlows: The explicit authentication flows.
            (string) --
            
    :type ExplicitAuthFlows: list
    """
    pass

def delete_user(AccessToken=None):
    """
    :param AccessToken: The access token from a request to delete a user.
            ReturnsNone
            
    :type AccessToken: string
    """
    pass

def delete_user_attributes(UserAttributeNames=None, AccessToken=None):
    """
    :param UserAttributeNames: [REQUIRED]
            An array of strings representing the user attribute names you wish to delete.
            (string) --
            
    :type UserAttributeNames: list
    :param AccessToken: The access token used in the request to delete user attributes.
    :type AccessToken: string
    """
    pass

def delete_user_pool(UserPoolId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool you want to delete.
            ReturnsNone
            
    :type UserPoolId: string
    """
    pass

def delete_user_pool_client(UserPoolId=None, ClientId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to delete the client.
            
    :type UserPoolId: string
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    """
    pass

def describe_user_import_job(UserPoolId=None, JobId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are being imported into.
            
    :type UserPoolId: string
    :param JobId: [REQUIRED]
            The job ID for the user import job.
            
    :type JobId: string
    """
    pass

def describe_user_pool(UserPoolId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool you want to describe.
            Return typedict
            ReturnsResponse Syntax{
              'UserPool': {
                'Id': 'string',
                'Name': 'string',
                'Policies': {
                  'PasswordPolicy': {
                    'MinimumLength': 123,
                    'RequireUppercase': True|False,
                    'RequireLowercase': True|False,
                    'RequireNumbers': True|False,
                    'RequireSymbols': True|False
                  }
                },
                'LambdaConfig': {
                  'PreSignUp': 'string',
                  'CustomMessage': 'string',
                  'PostConfirmation': 'string',
                  'PreAuthentication': 'string',
                  'PostAuthentication': 'string',
                  'DefineAuthChallenge': 'string',
                  'CreateAuthChallenge': 'string',
                  'VerifyAuthChallengeResponse': 'string'
                },
                'Status': 'Enabled'|'Disabled',
                'LastModifiedDate': datetime(2015, 1, 1),
                'CreationDate': datetime(2015, 1, 1),
                'SchemaAttributes': [
                  {
                    'Name': 'string',
                    'AttributeDataType': 'String'|'Number'|'DateTime'|'Boolean',
                    'DeveloperOnlyAttribute': True|False,
                    'Mutable': True|False,
                    'Required': True|False,
                    'NumberAttributeConstraints': {
                      'MinValue': 'string',
                      'MaxValue': 'string'
                    },
                    'StringAttributeConstraints': {
                      'MinLength': 'string',
                      'MaxLength': 'string'
                    }
                  },
                ],
                'AutoVerifiedAttributes': [
                  'phone_number'|'email',
                ],
                'AliasAttributes': [
                  'phone_number'|'email'|'preferred_username',
                ],
                'SmsVerificationMessage': 'string',
                'EmailVerificationMessage': 'string',
                'EmailVerificationSubject': 'string',
                'SmsAuthenticationMessage': 'string',
                'MfaConfiguration': 'OFF'|'ON'|'OPTIONAL',
                'DeviceConfiguration': {
                  'ChallengeRequiredOnNewDevice': True|False,
                  'DeviceOnlyRememberedOnUserPrompt': True|False
                },
                'EstimatedNumberOfUsers': 123,
                'EmailConfiguration': {
                  'SourceArn': 'string',
                  'ReplyToEmailAddress': 'string'
                },
                'SmsConfiguration': {
                  'SnsCallerArn': 'string',
                  'ExternalId': 'string'
                },
                'SmsConfigurationFailure': 'string',
                'EmailConfigurationFailure': 'string',
                'AdminCreateUserConfig': {
                  'AllowAdminCreateUserOnly': True|False,
                  'UnusedAccountValidityDays': 123,
                  'InviteMessageTemplate': {
                    'SMSMessage': 'string',
                    'EmailMessage': 'string',
                    'EmailSubject': 'string'
                  }
                }
              }
            }
            Response Structure
            (dict) --Represents the response to describe the user pool.
            UserPool (dict) --The container of metadata returned by the server to describe the pool.
            Id (string) --The ID of the user pool.
            Name (string) --The name of the user pool.
            Policies (dict) --A container describing the policies associated with a user pool.
            PasswordPolicy (dict) --A container with information about the user pool password policy.
            MinimumLength (integer) --The minimum length of the password policy that you have set. Cannot be less than 6.
            RequireUppercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.
            RequireLowercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.
            RequireNumbers (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one number in their password.
            RequireSymbols (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.
            
            LambdaConfig (dict) --A container describing the AWS Lambda triggers associated with a user pool.
            PreSignUp (string) --A pre-registration AWS Lambda trigger.
            CustomMessage (string) --A custom Message AWS Lambda trigger.
            PostConfirmation (string) --A post-confirmation AWS Lambda trigger.
            PreAuthentication (string) --A pre-authentication AWS Lambda trigger.
            PostAuthentication (string) --A post-authentication AWS Lambda trigger.
            DefineAuthChallenge (string) --Defines the authentication challenge.
            CreateAuthChallenge (string) --Creates an authentication challenge.
            VerifyAuthChallengeResponse (string) --Verifies the authentication challenge response.
            Status (string) --The status of a user pool.
            LastModifiedDate (datetime) --The last modified date of a user pool.
            CreationDate (datetime) --The creation date of a user pool.
            SchemaAttributes (list) --A container with the schema attributes of a user pool.
            (dict) --Contains information about the schema attribute.
            Name (string) --A schema attribute of the name type.
            AttributeDataType (string) --The attribute data type.
            DeveloperOnlyAttribute (boolean) --Specifies whether the attribute type is developer only.
            Mutable (boolean) --Specifies whether the attribute can be changed once it has been created.
            Required (boolean) --Specifies whether a user pool attribute is required. If the attribute is required and the user does not provide a value, registration or sign-in will fail.
            NumberAttributeConstraints (dict) --Specifies the constraints for an attribute of the number type.
            MinValue (string) --The minimum value of an attribute that is of the number data type.
            MaxValue (string) --The maximum value of an attribute that is of the number data type.
            StringAttributeConstraints (dict) --Specifies the constraints for an attribute of the string type.
            MinLength (string) --The minimum length of an attribute value of the string type.
            MaxLength (string) --The maximum length of an attribute value of the string type.
            
            AutoVerifiedAttributes (list) --Specifies the attributes that are auto-verified in a user pool.
            (string) --
            AliasAttributes (list) --Specifies the attributes that are aliased in a user pool.
            (string) --
            SmsVerificationMessage (string) --The contents of the SMS verification message.
            EmailVerificationMessage (string) --The contents of the email verification message.
            EmailVerificationSubject (string) --The subject of the email verification message.
            SmsAuthenticationMessage (string) --The contents of the SMS authentication message.
            MfaConfiguration (string) --Can be one of the following values:
            OFF - MFA tokens are not required and cannot be specified during user registration.
            ON - MFA tokens are required for all user registrations. You can only specify required when you are initially creating a user pool.
            OPTIONAL - Users have the option when registering to create an MFA token.
            DeviceConfiguration (dict) --The device configuration.
            ChallengeRequiredOnNewDevice (boolean) --Indicates whether a challenge is required on a new device. Only applicable to a new device.
            DeviceOnlyRememberedOnUserPrompt (boolean) --If true, a device is only remembered on user prompt.
            EstimatedNumberOfUsers (integer) --A number estimating the size of the user pool.
            EmailConfiguration (dict) --The email configuration.
            SourceArn (string) --The Amazon Resource Name (ARN) of the email source.
            ReplyToEmailAddress (string) --The REPLY-TO email address.
            SmsConfiguration (dict) --The SMS configuration.
            SnsCallerArn (string) --The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) caller.
            ExternalId (string) --The external ID.
            SmsConfigurationFailure (string) --The reason why the SMS configuration cannot send the message(s) to your users.
            EmailConfigurationFailure (string) --The reason why the email configuration cannot send the messages to your users.
            AdminCreateUserConfig (dict) --The configuration for AdminCreateUser requests.
            AllowAdminCreateUserOnly (boolean) --Set to True if only the administrator is allowed to create user profiles. Set to False if users can sign themselves up via an app.
            UnusedAccountValidityDays (integer) --The user account expiration limit, in days, after which the account is no longer usable. To reset the account after that time limit, you must call AdminCreateUser again, specifying 'RESEND' for the MessageAction parameter.
            InviteMessageTemplate (dict) --The message template to be used for the welcome message to new users.
            SMSMessage (string) --The message template for SMS messages.
            EmailMessage (string) --The message template for email messages.
            EmailSubject (string) --The subject line for email messages.
            
            
            
            
    :type UserPoolId: string
    """
    pass

def describe_user_pool_client(UserPoolId=None, ClientId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool you want to describe.
            
    :type UserPoolId: string
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    """
    pass

def forget_device(AccessToken=None, DeviceKey=None):
    """
    :param AccessToken: The access token for the forgotten device request.
    :type AccessToken: string
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    """
    pass

def forgot_password(ClientId=None, SecretHash=None, Username=None):
    """
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param SecretHash: A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
    :type SecretHash: string
    :param Username: [REQUIRED]
            The user name of the user for whom you want to enter a code to retrieve a forgotten password.
            
    :type Username: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_csv_header(UserPoolId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are to be imported into.
            Return typedict
            ReturnsResponse Syntax{
              'UserPoolId': 'string',
              'CSVHeader': [
                'string',
              ]
            }
            Response Structure
            (dict) --Represents the response from the server to the request to get the header information for the .csv file for the user import job.
            UserPoolId (string) --The user pool ID for the user pool that the users are to be imported into.
            CSVHeader (list) --The header information for the .csv file for the user import job.
            (string) --
            
            
    :type UserPoolId: string
    """
    pass

def get_device(DeviceKey=None, AccessToken=None):
    """
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    :param AccessToken: The access token.
    :type AccessToken: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_user(AccessToken=None):
    """
    :param AccessToken: The access token returned by the server response to get information about the user.
            Return typedict
            ReturnsResponse Syntax{
              'Username': 'string',
              'UserAttributes': [
                {
                  'Name': 'string',
                  'Value': 'string'
                },
              ],
              'MFAOptions': [
                {
                  'DeliveryMedium': 'SMS'|'EMAIL',
                  'AttributeName': 'string'
                },
              ]
            }
            Response Structure
            (dict) --Represents the response from the server from the request to get information about the user.
            Username (string) --The user name of the user you wish to retrieve from the get user request.
            UserAttributes (list) --An array of name-value pairs representing user attributes.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) --The name of the attribute.
            Value (string) --The value of the attribute.
            
            MFAOptions (list) --Specifies the options for MFA (e.g., email or phone number).
            (dict) --Specifies the different settings for multi-factor authentication (MFA).
            DeliveryMedium (string) --The delivery medium (email message or SMS message) to send the MFA code.
            AttributeName (string) --The attribute name of the MFA option type.
            
            
            
    :type AccessToken: string
    """
    pass

def get_user_attribute_verification_code(AccessToken=None, AttributeName=None):
    """
    :param AccessToken: The access token returned by the server response to get the user attribute verification code.
    :type AccessToken: string
    :param AttributeName: [REQUIRED]
            The attribute name returned by the server response to get the user attribute verification code.
            
    :type AttributeName: string
    """
    pass

def get_waiter():
    """
    """
    pass

def global_sign_out(AccessToken=None):
    """
    :param AccessToken: The access token.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --The response to the request to sign out all devices.
            
            
    :type AccessToken: string
    """
    pass

def initiate_auth(AuthFlow=None, AuthParameters=None, ClientMetadata=None, ClientId=None):
    """
    :param AuthFlow: [REQUIRED]
            The authentication flow.
            
    :type AuthFlow: string
    :param AuthParameters: The authentication parameters.
            (string) --
            (string) --
            
    :type AuthParameters: dict
    :param ClientMetadata: The client app's metadata.
            (string) --
            (string) --
            
    :type ClientMetadata: dict
    :param ClientId: [REQUIRED]
            The client ID.
            
    :type ClientId: string
    """
    pass

def list_devices(AccessToken=None, Limit=None, PaginationToken=None):
    """
    :param AccessToken: [REQUIRED]
            The access tokens for the request to list devices.
            
    :type AccessToken: string
    :param Limit: The limit of the device request.
    :type Limit: integer
    :param PaginationToken: The pagination token for the list request.
    :type PaginationToken: string
    """
    pass

def list_user_import_jobs(UserPoolId=None, MaxResults=None, PaginationToken=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are being imported into.
            
    :type UserPoolId: string
    :param MaxResults: [REQUIRED]
            The maximum number of import jobs you want the request to return.
            
    :type MaxResults: integer
    :param PaginationToken: An identifier that was returned from the previous call to ListUserImportJobs, which can be used to return the next set of import jobs in the list.
    :type PaginationToken: string
    """
    pass

def list_user_pool_clients(UserPoolId=None, MaxResults=None, NextToken=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to list user pool clients.
            
    :type UserPoolId: string
    :param MaxResults: The maximum number of results you want the request to return when listing the user pool clients.
    :type MaxResults: integer
    :param NextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type NextToken: string
    """
    pass

def list_user_pools(NextToken=None, MaxResults=None):
    """
    :param NextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type NextToken: string
    :param MaxResults: [REQUIRED]
            The maximum number of results you want the request to return when listing the user pools.
            
    :type MaxResults: integer
    """
    pass

def list_users(UserPoolId=None, AttributesToGet=None, Limit=None, PaginationToken=None, Filter=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for which you want to list users.
            
    :type UserPoolId: string
    :param AttributesToGet: The attributes to get from the request to list users.
            (string) --
            
    :type AttributesToGet: list
    :param Limit: The limit of the request to list users.
    :type Limit: integer
    :param PaginationToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type PaginationToken: string
    :param Filter: The filter for the list users request.
    :type Filter: string
    """
    pass

def resend_confirmation_code(ClientId=None, SecretHash=None, Username=None):
    """
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param SecretHash: A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
    :type SecretHash: string
    :param Username: [REQUIRED]
            The user name of the user to whom you wish to resend a confirmation code.
            
    :type Username: string
    """
    pass

def respond_to_auth_challenge(ClientId=None, ChallengeName=None, Session=None, ChallengeResponses=None):
    """
    :param ClientId: [REQUIRED]
            The client ID.
            
    :type ClientId: string
    :param ChallengeName: [REQUIRED]
            The name of the challenge.
            
    :type ChallengeName: string
    :param Session: The session.
    :type Session: string
    :param ChallengeResponses: The responses to the authentication challenge.
            (string) --
            (string) --
            
    :type ChallengeResponses: dict
    """
    pass

def set_user_settings(AccessToken=None, MFAOptions=None):
    """
    :param AccessToken: [REQUIRED]
            The access token for the set user settings request.
            
    :type AccessToken: string
    :param MFAOptions: [REQUIRED]
            Specifies the options for MFA (e.g., email or phone number).
            (dict) --Specifies the different settings for multi-factor authentication (MFA).
            DeliveryMedium (string) --The delivery medium (email message or SMS message) to send the MFA code.
            AttributeName (string) --The attribute name of the MFA option type.
            
            
    :type MFAOptions: list
    """
    pass

def sign_up(ClientId=None, SecretHash=None, Username=None, Password=None, UserAttributes=None, ValidationData=None):
    """
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param SecretHash: A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
    :type SecretHash: string
    :param Username: [REQUIRED]
            The user name of the user you wish to register.
            
    :type Username: string
    :param Password: [REQUIRED]
            The password of the user you wish to register.
            
    :type Password: string
    :param UserAttributes: An array of name-value pairs representing user attributes.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type UserAttributes: list
    :param ValidationData: The validation data in the request to register a user.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type ValidationData: list
    """
    pass

def start_user_import_job(UserPoolId=None, JobId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are being imported into.
            
    :type UserPoolId: string
    :param JobId: [REQUIRED]
            The job ID for the user import job.
            
    :type JobId: string
    """
    pass

def stop_user_import_job(UserPoolId=None, JobId=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool that the users are being imported into.
            
    :type UserPoolId: string
    :param JobId: [REQUIRED]
            The job ID for the user import job.
            
    :type JobId: string
    """
    pass

def update_device_status(AccessToken=None, DeviceKey=None, DeviceRememberedStatus=None):
    """
    :param AccessToken: [REQUIRED]
            The access token.
            
    :type AccessToken: string
    :param DeviceKey: [REQUIRED]
            The device key.
            
    :type DeviceKey: string
    :param DeviceRememberedStatus: The status of whether a device is remembered.
    :type DeviceRememberedStatus: string
    """
    pass

def update_user_attributes(UserAttributes=None, AccessToken=None):
    """
    :param UserAttributes: [REQUIRED]
            An array of name-value pairs representing user attributes.
            (dict) --Specifies whether the attribute is standard or custom.
            Name (string) -- [REQUIRED]The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type UserAttributes: list
    :param AccessToken: The access token for the request to update user attributes.
    :type AccessToken: string
    """
    pass

def update_user_pool(UserPoolId=None, Policies=None, LambdaConfig=None, AutoVerifiedAttributes=None, SmsVerificationMessage=None, EmailVerificationMessage=None, EmailVerificationSubject=None, SmsAuthenticationMessage=None, MfaConfiguration=None, DeviceConfiguration=None, EmailConfiguration=None, SmsConfiguration=None, AdminCreateUserConfig=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool you want to update.
            
    :type UserPoolId: string
    :param Policies: A container with the policies you wish to update in a user pool.
            PasswordPolicy (dict) --A container with information about the user pool password policy.
            MinimumLength (integer) --The minimum length of the password policy that you have set. Cannot be less than 6.
            RequireUppercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.
            RequireLowercase (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.
            RequireNumbers (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one number in their password.
            RequireSymbols (boolean) --In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.
            
            
    :type Policies: dict
    :param LambdaConfig: The AWS Lambda configuration information from the request to update the user pool.
            PreSignUp (string) --A pre-registration AWS Lambda trigger.
            CustomMessage (string) --A custom Message AWS Lambda trigger.
            PostConfirmation (string) --A post-confirmation AWS Lambda trigger.
            PreAuthentication (string) --A pre-authentication AWS Lambda trigger.
            PostAuthentication (string) --A post-authentication AWS Lambda trigger.
            DefineAuthChallenge (string) --Defines the authentication challenge.
            CreateAuthChallenge (string) --Creates an authentication challenge.
            VerifyAuthChallengeResponse (string) --Verifies the authentication challenge response.
            
    :type LambdaConfig: dict
    :param AutoVerifiedAttributes: The attributes that are automatically verified when the Amazon Cognito service makes a request to update user pools.
            (string) --
            
    :type AutoVerifiedAttributes: list
    :param SmsVerificationMessage: A container with information about the SMS verification message.
    :type SmsVerificationMessage: string
    :param EmailVerificationMessage: The contents of the email verification message.
    :type EmailVerificationMessage: string
    :param EmailVerificationSubject: The subject of the email verfication message.
    :type EmailVerificationSubject: string
    :param SmsAuthenticationMessage: The contents of the SMS authentication message.
    :type SmsAuthenticationMessage: string
    :param MfaConfiguration: Can be one of the following values:
            OFF - MFA tokens are not required and cannot be specified during user registration.
            ON - MFA tokens are required for all user registrations. You can only specify required when you are initially creating a user pool.
            OPTIONAL - Users have the option when registering to create an MFA token.
            
    :type MfaConfiguration: string
    :param DeviceConfiguration: Device configuration.
            ChallengeRequiredOnNewDevice (boolean) --Indicates whether a challenge is required on a new device. Only applicable to a new device.
            DeviceOnlyRememberedOnUserPrompt (boolean) --If true, a device is only remembered on user prompt.
            
    :type DeviceConfiguration: dict
    :param EmailConfiguration: Email configuration.
            SourceArn (string) --The Amazon Resource Name (ARN) of the email source.
            ReplyToEmailAddress (string) --The REPLY-TO email address.
            
    :type EmailConfiguration: dict
    :param SmsConfiguration: SMS configuration.
            SnsCallerArn (string) --The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) caller.
            ExternalId (string) --The external ID.
            
    :type SmsConfiguration: dict
    :param AdminCreateUserConfig: The configuration for AdminCreateUser requests.
            AllowAdminCreateUserOnly (boolean) --Set to True if only the administrator is allowed to create user profiles. Set to False if users can sign themselves up via an app.
            UnusedAccountValidityDays (integer) --The user account expiration limit, in days, after which the account is no longer usable. To reset the account after that time limit, you must call AdminCreateUser again, specifying 'RESEND' for the MessageAction parameter.
            InviteMessageTemplate (dict) --The message template to be used for the welcome message to new users.
            SMSMessage (string) --The message template for SMS messages.
            EmailMessage (string) --The message template for email messages.
            EmailSubject (string) --The subject line for email messages.
            
            
    :type AdminCreateUserConfig: dict
    """
    pass

def update_user_pool_client(UserPoolId=None, ClientId=None, ClientName=None, RefreshTokenValidity=None, ReadAttributes=None, WriteAttributes=None, ExplicitAuthFlows=None):
    """
    :param UserPoolId: [REQUIRED]
            The user pool ID for the user pool where you want to update the user pool client.
            
    :type UserPoolId: string
    :param ClientId: [REQUIRED]
            The ID of the client associated with the user pool.
            
    :type ClientId: string
    :param ClientName: The client name from the update user pool client request.
    :type ClientName: string
    :param RefreshTokenValidity: The validity of the refresh token.
    :type RefreshTokenValidity: integer
    :param ReadAttributes: The read-only attributes of the user pool.
            (string) --
            
    :type ReadAttributes: list
    :param WriteAttributes: The writeable attributes of the user pool.
            (string) --
            
    :type WriteAttributes: list
    :param ExplicitAuthFlows: Explicit authentication flows.
            (string) --
            
    :type ExplicitAuthFlows: list
    """
    pass

def verify_user_attribute(AccessToken=None, AttributeName=None, Code=None):
    """
    :param AccessToken: Represents the access token of the request to verify user attributes.
    :type AccessToken: string
    :param AttributeName: [REQUIRED]
            The attribute name in the request to verify user attributes.
            
    :type AttributeName: string
    :param Code: [REQUIRED]
            The verification code in the request to verify user attributes.
            
    :type Code: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def batch_get_repositories(repositoryNames=None):
    """
    :param repositoryNames: [REQUIRED]
            The names of the repositories to get information about.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'repositories': [
                {
                  'accountId': 'string',
                  'repositoryId': 'string',
                  'repositoryName': 'string',
                  'repositoryDescription': 'string',
                  'defaultBranch': 'string',
                  'lastModifiedDate': datetime(2015, 1, 1),
                  'creationDate': datetime(2015, 1, 1),
                  'cloneUrlHttp': 'string',
                  'cloneUrlSsh': 'string',
                  'Arn': 'string'
                },
              ],
              'repositoriesNotFound': [
                'string',
              ]
            }
            Response Structure
            (dict) --Represents the output of a batch get repositories operation.
            repositories (list) --A list of repositories returned by the batch get repositories operation.
            (dict) --Information about a repository.
            accountId (string) --The ID of the AWS account associated with the repository.
            repositoryId (string) --The ID of the repository.
            repositoryName (string) --The repository's name.
            repositoryDescription (string) --A comment or description about the repository.
            defaultBranch (string) --The repository's default branch name.
            lastModifiedDate (datetime) --The date and time the repository was last modified, in timestamp format.
            creationDate (datetime) --The date and time the repository was created, in timestamp format.
            cloneUrlHttp (string) --The URL to use for cloning the repository over HTTPS.
            cloneUrlSsh (string) --The URL to use for cloning the repository over SSH.
            Arn (string) --The Amazon Resource Name (ARN) of the repository.
            
            repositoriesNotFound (list) --Returns a list of repository names for which information could not be found.
            (string) --
            
            
    :type repositoryNames: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_branch(repositoryName=None, branchName=None, commitId=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository in which you want to create the new branch.
            
    :type repositoryName: string
    :param branchName: [REQUIRED]
            The name of the new branch to create.
            
    :type branchName: string
    :param commitId: [REQUIRED]
            The ID of the commit to point the new branch to.
            
    :type commitId: string
    """
    pass

def create_repository(repositoryName=None, repositoryDescription=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the new repository to be created.
            Note
            The repository name must be unique across the calling AWS account. In addition, repository names are limited to 100 alphanumeric, dash, and underscore characters, and cannot include certain characters. For a full description of the limits on repository names, see Limits in the AWS CodeCommit User Guide. The suffix '.git' is prohibited.
            
    :type repositoryName: string
    :param repositoryDescription: A comment or description about the new repository.
            Note
            The description field for a repository accepts all HTML characters and all valid Unicode characters. Applications that do not HTML-encode the description and display it in a web page could expose users to potentially malicious code. Make sure that you HTML-encode the description field in any application that uses this API to display the repository description on a web page.
            
    :type repositoryDescription: string
    """
    pass

def delete_repository(repositoryName=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository to delete.
            Return typedict
            ReturnsResponse Syntax{
              'repositoryId': 'string'
            }
            Response Structure
            (dict) --Represents the output of a delete repository operation.
            repositoryId (string) --The ID of the repository that was deleted.
            
            
    :type repositoryName: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_branch(repositoryName=None, branchName=None):
    """
    :param repositoryName: The name of the repository that contains the branch for which you want to retrieve information.
    :type repositoryName: string
    :param branchName: The name of the branch for which you want to retrieve information.
    :type branchName: string
    """
    pass

def get_commit(repositoryName=None, commitId=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository to which the commit was made.
            
    :type repositoryName: string
    :param commitId: [REQUIRED]
            The commit ID.
            
    :type commitId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_repository(repositoryName=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository to get information about.
            Return typedict
            ReturnsResponse Syntax{
              'repositoryMetadata': {
                'accountId': 'string',
                'repositoryId': 'string',
                'repositoryName': 'string',
                'repositoryDescription': 'string',
                'defaultBranch': 'string',
                'lastModifiedDate': datetime(2015, 1, 1),
                'creationDate': datetime(2015, 1, 1),
                'cloneUrlHttp': 'string',
                'cloneUrlSsh': 'string',
                'Arn': 'string'
              }
            }
            Response Structure
            (dict) --Represents the output of a get repository operation.
            repositoryMetadata (dict) --Information about the repository.
            accountId (string) --The ID of the AWS account associated with the repository.
            repositoryId (string) --The ID of the repository.
            repositoryName (string) --The repository's name.
            repositoryDescription (string) --A comment or description about the repository.
            defaultBranch (string) --The repository's default branch name.
            lastModifiedDate (datetime) --The date and time the repository was last modified, in timestamp format.
            creationDate (datetime) --The date and time the repository was created, in timestamp format.
            cloneUrlHttp (string) --The URL to use for cloning the repository over HTTPS.
            cloneUrlSsh (string) --The URL to use for cloning the repository over SSH.
            Arn (string) --The Amazon Resource Name (ARN) of the repository.
            
            
            
    :type repositoryName: string
    """
    pass

def get_repository_triggers(repositoryName=None):
    """
    :param repositoryName: The name of the repository for which the trigger is configured.
            Return typedict
            ReturnsResponse Syntax{
              'configurationId': 'string',
              'triggers': [
                {
                  'name': 'string',
                  'destinationArn': 'string',
                  'customData': 'string',
                  'branches': [
                    'string',
                  ],
                  'events': [
                    'all'|'updateReference'|'createReference'|'deleteReference',
                  ]
                },
              ]
            }
            Response Structure
            (dict) --Represents the output of a get repository triggers operation.
            configurationId (string) --The system-generated unique ID for the trigger.
            triggers (list) --The JSON block of configuration information for each trigger.
            (dict) --Information about a trigger for a repository.
            name (string) --The name of the trigger.
            destinationArn (string) --The ARN of the resource that is the target for a trigger. For example, the ARN of a topic in Amazon Simple Notification Service (SNS).
            customData (string) --Any custom data associated with the trigger that will be included in the information sent to the target of the trigger.
            branches (list) --The branches that will be included in the trigger configuration. If no branches are specified, the trigger will apply to all branches.
            (string) --
            events (list) --The repository events that will cause the trigger to run actions in another service, such as sending a notification through Amazon Simple Notification Service (SNS). If no events are specified, the trigger will run for all repository events.
            (string) --
            
            
            
    :type repositoryName: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_branches(repositoryName=None, nextToken=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository that contains the branches.
            
    :type repositoryName: string
    :param nextToken: An enumeration token that allows the operation to batch the results.
    :type nextToken: string
    """
    pass

def list_repositories(nextToken=None, sortBy=None, order=None):
    """
    :param nextToken: An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.
    :type nextToken: string
    :param sortBy: The criteria used to sort the results of a list repositories operation.
    :type sortBy: string
    :param order: The order in which to sort the results of a list repositories operation.
    :type order: string
    """
    pass

def put_repository_triggers(repositoryName=None, triggers=None):
    """
    :param repositoryName: The name of the repository where you want to create or update the trigger.
    :type repositoryName: string
    :param triggers: The JSON block of configuration information for each trigger.
            (dict) --Information about a trigger for a repository.
            name (string) --The name of the trigger.
            destinationArn (string) --The ARN of the resource that is the target for a trigger. For example, the ARN of a topic in Amazon Simple Notification Service (SNS).
            customData (string) --Any custom data associated with the trigger that will be included in the information sent to the target of the trigger.
            branches (list) --The branches that will be included in the trigger configuration. If no branches are specified, the trigger will apply to all branches.
            (string) --
            events (list) --The repository events that will cause the trigger to run actions in another service, such as sending a notification through Amazon Simple Notification Service (SNS). If no events are specified, the trigger will run for all repository events.
            (string) --
            
            
    :type triggers: list
    """
    pass

def test_repository_triggers(repositoryName=None, triggers=None):
    """
    :param repositoryName: The name of the repository in which to test the triggers.
    :type repositoryName: string
    :param triggers: The list of triggers to test.
            (dict) --Information about a trigger for a repository.
            name (string) --The name of the trigger.
            destinationArn (string) --The ARN of the resource that is the target for a trigger. For example, the ARN of a topic in Amazon Simple Notification Service (SNS).
            customData (string) --Any custom data associated with the trigger that will be included in the information sent to the target of the trigger.
            branches (list) --The branches that will be included in the trigger configuration. If no branches are specified, the trigger will apply to all branches.
            (string) --
            events (list) --The repository events that will cause the trigger to run actions in another service, such as sending a notification through Amazon Simple Notification Service (SNS). If no events are specified, the trigger will run for all repository events.
            (string) --
            
            
    :type triggers: list
    """
    pass

def update_default_branch(repositoryName=None, defaultBranchName=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository to set or change the default branch for.
            
    :type repositoryName: string
    :param defaultBranchName: [REQUIRED]
            The name of the branch to set as the default.
            
    :type defaultBranchName: string
    """
    pass

def update_repository_description(repositoryName=None, repositoryDescription=None):
    """
    :param repositoryName: [REQUIRED]
            The name of the repository to set or change the comment or description for.
            
    :type repositoryName: string
    :param repositoryDescription: The new comment or description for the specified repository. Repository descriptions are limited to 1,000 characters.
    :type repositoryDescription: string
    """
    pass

def update_repository_name(oldName=None, newName=None):
    """
    :param oldName: [REQUIRED]
            The existing name of the repository.
            
    :type oldName: string
    :param newName: [REQUIRED]
            The new name for the repository.
            
    :type newName: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def allocate_connection_on_interconnect(bandwidth=None, connectionName=None, ownerAccount=None, interconnectId=None, vlan=None):
    """
    :param bandwidth: [REQUIRED]
            Bandwidth of the connection.
            Example: '500Mbps '
            Default: None
            Values: 50M, 100M, 200M, 300M, 400M, or 500M
            
    :type bandwidth: string
    :param connectionName: [REQUIRED]
            Name of the provisioned connection.
            Example: '500M Connection to AWS '
            Default: None
            
    :type connectionName: string
    :param ownerAccount: [REQUIRED]
            Numeric account Id of the customer for whom the connection will be provisioned.
            Example: 123443215678
            Default: None
            
    :type ownerAccount: string
    :param interconnectId: [REQUIRED]
            ID of the interconnect on which the connection will be provisioned.
            Example: dxcon-456abc78
            Default: None
            
    :type interconnectId: string
    :param vlan: [REQUIRED]
            The dedicated VLAN provisioned to the connection.
            Example: 101
            Default: None
            
    :type vlan: integer
    """
    pass

def allocate_private_virtual_interface(connectionId=None, ownerAccount=None, newPrivateVirtualInterfaceAllocation=None):
    """
    :param connectionId: [REQUIRED]
            The connection ID on which the private virtual interface is provisioned.
            Default: None
            
    :type connectionId: string
    :param ownerAccount: [REQUIRED]
            The AWS account that will own the new private virtual interface.
            Default: None
            
    :type ownerAccount: string
    :param newPrivateVirtualInterfaceAllocation: [REQUIRED]
            Detailed information for the private virtual interface to be provisioned.
            Default: None
            virtualInterfaceName (string) -- [REQUIRED]The name of the virtual interface assigned by the customer.
            Example: 'My VPC'
            vlan (integer) -- [REQUIRED]The VLAN ID.
            Example: 101
            asn (integer) -- [REQUIRED]Autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
            Example: 65000
            authKey (string) --Authentication key for BGP configuration.
            Example: asdf34example
            amazonAddress (string) --IP address assigned to the Amazon interface.
            Example: 192.168.1.1/30
            customerAddress (string) --IP address assigned to the customer interface.
            Example: 192.168.1.2/30
            
    :type newPrivateVirtualInterfaceAllocation: dict
    """
    pass

def allocate_public_virtual_interface(connectionId=None, ownerAccount=None, newPublicVirtualInterfaceAllocation=None):
    """
    :param connectionId: [REQUIRED]
            The connection ID on which the public virtual interface is provisioned.
            Default: None
            
    :type connectionId: string
    :param ownerAccount: [REQUIRED]
            The AWS account that will own the new public virtual interface.
            Default: None
            
    :type ownerAccount: string
    :param newPublicVirtualInterfaceAllocation: [REQUIRED]
            Detailed information for the public virtual interface to be provisioned.
            Default: None
            virtualInterfaceName (string) -- [REQUIRED]The name of the virtual interface assigned by the customer.
            Example: 'My VPC'
            vlan (integer) -- [REQUIRED]The VLAN ID.
            Example: 101
            asn (integer) -- [REQUIRED]Autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
            Example: 65000
            authKey (string) --Authentication key for BGP configuration.
            Example: asdf34example
            amazonAddress (string) -- [REQUIRED]IP address assigned to the Amazon interface.
            Example: 192.168.1.1/30
            customerAddress (string) -- [REQUIRED]IP address assigned to the customer interface.
            Example: 192.168.1.2/30
            routeFilterPrefixes (list) -- [REQUIRED]A list of routes to be advertised to the AWS network in this region (public virtual interface).
            (dict) --A route filter prefix that the customer can advertise through Border Gateway Protocol (BGP) over a public virtual interface.
            cidr (string) --CIDR notation for the advertised route. Multiple routes are separated by commas.
            Example: 10.10.10.0/24,10.10.11.0/24
            
            
    :type newPublicVirtualInterfaceAllocation: dict
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def confirm_connection(connectionId=None):
    """
    :param connectionId: [REQUIRED]
            ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'connectionState': 'ordering'|'requested'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected'
            }
            Response Structure
            (dict) --The response received when ConfirmConnection is called.
            connectionState (string) --State of the connection.
            Ordering : The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order.
            Requested : The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The connection has been approved, and is being initialized.
            Available : The network link is up, and the connection is ready for use.
            Down : The network link is down.
            Deleting : The connection is in the process of being deleted.
            Deleted : The connection has been deleted.
            Rejected : A hosted connection in the 'Ordering' state will enter the 'Rejected' state if it is deleted by the end customer.
            
            
    :type connectionId: string
    """
    pass

def confirm_private_virtual_interface(virtualInterfaceId=None, virtualGatewayId=None):
    """
    :param virtualInterfaceId: [REQUIRED]
            ID of the virtual interface.
            Example: dxvif-123dfg56
            Default: None
            
    :type virtualInterfaceId: string
    :param virtualGatewayId: [REQUIRED]
            ID of the virtual private gateway that will be attached to the virtual interface.
            A virtual private gateway can be managed via the Amazon Virtual Private Cloud (VPC) console or the EC2 CreateVpnGateway action.
            Default: None
            
    :type virtualGatewayId: string
    """
    pass

def confirm_public_virtual_interface(virtualInterfaceId=None):
    """
    :param virtualInterfaceId: [REQUIRED]
            ID of the virtual interface.
            Example: dxvif-123dfg56
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'virtualInterfaceState': 'confirming'|'verifying'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected'
            }
            Response Structure
            (dict) --The response received when ConfirmPublicVirtualInterface is called.
            virtualInterfaceState (string) --State of the virtual interface.
            Confirming : The creation of the virtual interface is pending confirmation from the virtual interface owner. If the owner of the virtual interface is different from the owner of the connection on which it is provisioned, then the virtual interface will remain in this state until it is confirmed by the virtual interface owner.
            Verifying : This state only applies to public virtual interfaces. Each public virtual interface needs validation before the virtual interface can be created.
            Pending : A virtual interface is in this state from the time that it is created until the virtual interface is ready to forward traffic.
            Available : A virtual interface that is able to forward traffic.
            Down : A virtual interface that is BGP down.
            Deleting : A virtual interface is in this state immediately after calling DeleteVirtualInterface until it can no longer forward traffic.
            Deleted : A virtual interface that cannot forward traffic.
            Rejected : The virtual interface owner has declined creation of the virtual interface. If a virtual interface in the 'Confirming' state is deleted by the virtual interface owner, the virtual interface will enter the 'Rejected' state.
            
            
    :type virtualInterfaceId: string
    """
    pass

def create_connection(location=None, bandwidth=None, connectionName=None):
    """
    :param location: [REQUIRED]
            Where the connection is located.
            Example: EqSV5
            Default: None
            
    :type location: string
    :param bandwidth: [REQUIRED]
            Bandwidth of the connection.
            Example: 1Gbps
            Default: None
            
    :type bandwidth: string
    :param connectionName: [REQUIRED]
            The name of the connection.
            Example: 'My Connection to AWS '
            Default: None
            
    :type connectionName: string
    """
    pass

def create_interconnect(interconnectName=None, bandwidth=None, location=None):
    """
    :param interconnectName: [REQUIRED]
            The name of the interconnect.
            Example: '1G Interconnect to AWS '
            Default: None
            
    :type interconnectName: string
    :param bandwidth: [REQUIRED]
            The port bandwidth
            Example: 1Gbps
            Default: None
            Available values: 1Gbps,10Gbps
            
    :type bandwidth: string
    :param location: [REQUIRED]
            Where the interconnect is located
            Example: EqSV5
            Default: None
            
    :type location: string
    """
    pass

def create_private_virtual_interface(connectionId=None, newPrivateVirtualInterface=None):
    """
    :param connectionId: [REQUIRED]
            ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            
    :type connectionId: string
    :param newPrivateVirtualInterface: [REQUIRED]
            Detailed information for the private virtual interface to be created.
            Default: None
            virtualInterfaceName (string) -- [REQUIRED]The name of the virtual interface assigned by the customer.
            Example: 'My VPC'
            vlan (integer) -- [REQUIRED]The VLAN ID.
            Example: 101
            asn (integer) -- [REQUIRED]Autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
            Example: 65000
            authKey (string) --Authentication key for BGP configuration.
            Example: asdf34example
            amazonAddress (string) --IP address assigned to the Amazon interface.
            Example: 192.168.1.1/30
            customerAddress (string) --IP address assigned to the customer interface.
            Example: 192.168.1.2/30
            virtualGatewayId (string) -- [REQUIRED]The ID of the virtual private gateway to a VPC. This only applies to private virtual interfaces.
            Example: vgw-123er56
            
    :type newPrivateVirtualInterface: dict
    """
    pass

def create_public_virtual_interface(connectionId=None, newPublicVirtualInterface=None):
    """
    :param connectionId: [REQUIRED]
            ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            
    :type connectionId: string
    :param newPublicVirtualInterface: [REQUIRED]
            Detailed information for the public virtual interface to be created.
            Default: None
            virtualInterfaceName (string) -- [REQUIRED]The name of the virtual interface assigned by the customer.
            Example: 'My VPC'
            vlan (integer) -- [REQUIRED]The VLAN ID.
            Example: 101
            asn (integer) -- [REQUIRED]Autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
            Example: 65000
            authKey (string) --Authentication key for BGP configuration.
            Example: asdf34example
            amazonAddress (string) -- [REQUIRED]IP address assigned to the Amazon interface.
            Example: 192.168.1.1/30
            customerAddress (string) -- [REQUIRED]IP address assigned to the customer interface.
            Example: 192.168.1.2/30
            routeFilterPrefixes (list) -- [REQUIRED]A list of routes to be advertised to the AWS network in this region (public virtual interface).
            (dict) --A route filter prefix that the customer can advertise through Border Gateway Protocol (BGP) over a public virtual interface.
            cidr (string) --CIDR notation for the advertised route. Multiple routes are separated by commas.
            Example: 10.10.10.0/24,10.10.11.0/24
            
            
    :type newPublicVirtualInterface: dict
    """
    pass

def delete_connection(connectionId=None):
    """
    :param connectionId: [REQUIRED]
            ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'ownerAccount': 'string',
              'connectionId': 'string',
              'connectionName': 'string',
              'connectionState': 'ordering'|'requested'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected',
              'region': 'string',
              'location': 'string',
              'bandwidth': 'string',
              'vlan': 123,
              'partnerName': 'string',
              'loaIssueTime': datetime(2015, 1, 1)
            }
            Response Structure
            (dict) --A connection represents the physical network connection between the AWS Direct Connect location and the customer.
            ownerAccount (string) --The AWS account that will own the new connection.
            connectionId (string) --ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            connectionName (string) --The name of the connection.
            Example: 'My Connection to AWS '
            Default: None
            connectionState (string) --State of the connection.
            Ordering : The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order.
            Requested : The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The connection has been approved, and is being initialized.
            Available : The network link is up, and the connection is ready for use.
            Down : The network link is down.
            Deleting : The connection is in the process of being deleted.
            Deleted : The connection has been deleted.
            Rejected : A hosted connection in the 'Ordering' state will enter the 'Rejected' state if it is deleted by the end customer.
            region (string) --The AWS region where the connection is located.
            Example: us-east-1
            Default: None
            location (string) --Where the connection is located.
            Example: EqSV5
            Default: None
            bandwidth (string) --Bandwidth of the connection.
            Example: 1Gbps (for regular connections), or 500Mbps (for hosted connections)
            Default: None
            vlan (integer) --The VLAN ID.
            Example: 101
            partnerName (string) --The name of the AWS Direct Connect service provider associated with the connection.
            loaIssueTime (datetime) --The time of the most recent call to DescribeConnectionLoa for this Connection.
            
            
    :type connectionId: string
    """
    pass

def delete_interconnect(interconnectId=None):
    """
    :param interconnectId: [REQUIRED]
            The ID of the interconnect.
            Example: dxcon-abc123
            Return typedict
            ReturnsResponse Syntax{
              'interconnectState': 'requested'|'pending'|'available'|'down'|'deleting'|'deleted'
            }
            Response Structure
            (dict) --The response received when DeleteInterconnect is called.
            interconnectState (string) --State of the interconnect.
            Requested : The initial state of an interconnect. The interconnect stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The interconnect has been approved, and is being initialized.
            Available : The network link is up, and the interconnect is ready for use.
            Down : The network link is down.
            Deleting : The interconnect is in the process of being deleted.
            Deleted : The interconnect has been deleted.
            
            
    :type interconnectId: string
    """
    pass

def delete_virtual_interface(virtualInterfaceId=None):
    """
    :param virtualInterfaceId: [REQUIRED]
            ID of the virtual interface.
            Example: dxvif-123dfg56
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'virtualInterfaceState': 'confirming'|'verifying'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected'
            }
            Response Structure
            (dict) --The response received when DeleteVirtualInterface is called.
            virtualInterfaceState (string) --State of the virtual interface.
            Confirming : The creation of the virtual interface is pending confirmation from the virtual interface owner. If the owner of the virtual interface is different from the owner of the connection on which it is provisioned, then the virtual interface will remain in this state until it is confirmed by the virtual interface owner.
            Verifying : This state only applies to public virtual interfaces. Each public virtual interface needs validation before the virtual interface can be created.
            Pending : A virtual interface is in this state from the time that it is created until the virtual interface is ready to forward traffic.
            Available : A virtual interface that is able to forward traffic.
            Down : A virtual interface that is BGP down.
            Deleting : A virtual interface is in this state immediately after calling DeleteVirtualInterface until it can no longer forward traffic.
            Deleted : A virtual interface that cannot forward traffic.
            Rejected : The virtual interface owner has declined creation of the virtual interface. If a virtual interface in the 'Confirming' state is deleted by the virtual interface owner, the virtual interface will enter the 'Rejected' state.
            
            
    :type virtualInterfaceId: string
    """
    pass

def describe_connection_loa(connectionId=None, providerName=None, loaContentType=None):
    """
    :param connectionId: [REQUIRED]
            ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            
    :type connectionId: string
    :param providerName: The name of the APN partner or service provider who establishes connectivity on your behalf. If you supply this parameter, the LOA-CFA lists the provider name alongside your company name as the requester of the cross connect.
            Default: None
            
    :type providerName: string
    :param loaContentType: A standard media type indicating the content type of the LOA-CFA document. Currently, the only supported value is 'application/pdf'.
            Default: application/pdf
            
    :type loaContentType: string
    """
    pass

def describe_connections(connectionId=None):
    """
    :param connectionId: ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'connections': [
                {
                  'ownerAccount': 'string',
                  'connectionId': 'string',
                  'connectionName': 'string',
                  'connectionState': 'ordering'|'requested'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected',
                  'region': 'string',
                  'location': 'string',
                  'bandwidth': 'string',
                  'vlan': 123,
                  'partnerName': 'string',
                  'loaIssueTime': datetime(2015, 1, 1)
                },
              ]
            }
            Response Structure
            (dict) --A structure containing a list of connections.
            connections (list) --A list of connections.
            (dict) --A connection represents the physical network connection between the AWS Direct Connect location and the customer.
            ownerAccount (string) --The AWS account that will own the new connection.
            connectionId (string) --ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            connectionName (string) --The name of the connection.
            Example: 'My Connection to AWS '
            Default: None
            connectionState (string) --State of the connection.
            Ordering : The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order.
            Requested : The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The connection has been approved, and is being initialized.
            Available : The network link is up, and the connection is ready for use.
            Down : The network link is down.
            Deleting : The connection is in the process of being deleted.
            Deleted : The connection has been deleted.
            Rejected : A hosted connection in the 'Ordering' state will enter the 'Rejected' state if it is deleted by the end customer.
            region (string) --The AWS region where the connection is located.
            Example: us-east-1
            Default: None
            location (string) --Where the connection is located.
            Example: EqSV5
            Default: None
            bandwidth (string) --Bandwidth of the connection.
            Example: 1Gbps (for regular connections), or 500Mbps (for hosted connections)
            Default: None
            vlan (integer) --The VLAN ID.
            Example: 101
            partnerName (string) --The name of the AWS Direct Connect service provider associated with the connection.
            loaIssueTime (datetime) --The time of the most recent call to DescribeConnectionLoa for this Connection.
            
            
            
    :type connectionId: string
    """
    pass

def describe_connections_on_interconnect(interconnectId=None):
    """
    :param interconnectId: [REQUIRED]
            ID of the interconnect on which a list of connection is provisioned.
            Example: dxcon-abc123
            Default: None
            Return typedict
            ReturnsResponse Syntax{
              'connections': [
                {
                  'ownerAccount': 'string',
                  'connectionId': 'string',
                  'connectionName': 'string',
                  'connectionState': 'ordering'|'requested'|'pending'|'available'|'down'|'deleting'|'deleted'|'rejected',
                  'region': 'string',
                  'location': 'string',
                  'bandwidth': 'string',
                  'vlan': 123,
                  'partnerName': 'string',
                  'loaIssueTime': datetime(2015, 1, 1)
                },
              ]
            }
            Response Structure
            (dict) --A structure containing a list of connections.
            connections (list) --A list of connections.
            (dict) --A connection represents the physical network connection between the AWS Direct Connect location and the customer.
            ownerAccount (string) --The AWS account that will own the new connection.
            connectionId (string) --ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            connectionName (string) --The name of the connection.
            Example: 'My Connection to AWS '
            Default: None
            connectionState (string) --State of the connection.
            Ordering : The initial state of a hosted connection provisioned on an interconnect. The connection stays in the ordering state until the owner of the hosted connection confirms or declines the connection order.
            Requested : The initial state of a standard connection. The connection stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The connection has been approved, and is being initialized.
            Available : The network link is up, and the connection is ready for use.
            Down : The network link is down.
            Deleting : The connection is in the process of being deleted.
            Deleted : The connection has been deleted.
            Rejected : A hosted connection in the 'Ordering' state will enter the 'Rejected' state if it is deleted by the end customer.
            region (string) --The AWS region where the connection is located.
            Example: us-east-1
            Default: None
            location (string) --Where the connection is located.
            Example: EqSV5
            Default: None
            bandwidth (string) --Bandwidth of the connection.
            Example: 1Gbps (for regular connections), or 500Mbps (for hosted connections)
            Default: None
            vlan (integer) --The VLAN ID.
            Example: 101
            partnerName (string) --The name of the AWS Direct Connect service provider associated with the connection.
            loaIssueTime (datetime) --The time of the most recent call to DescribeConnectionLoa for this Connection.
            
            
            
    :type interconnectId: string
    """
    pass

def describe_interconnect_loa(interconnectId=None, providerName=None, loaContentType=None):
    """
    :param interconnectId: [REQUIRED]
            The ID of the interconnect.
            Example: dxcon-abc123
            
    :type interconnectId: string
    :param providerName: The name of the service provider who establishes connectivity on your behalf. If you supply this parameter, the LOA-CFA lists the provider name alongside your company name as the requester of the cross connect.
            Default: None
            
    :type providerName: string
    :param loaContentType: A standard media type indicating the content type of the LOA-CFA document. Currently, the only supported value is 'application/pdf'.
            Default: application/pdf
            
    :type loaContentType: string
    """
    pass

def describe_interconnects(interconnectId=None):
    """
    :param interconnectId: The ID of the interconnect.
            Example: dxcon-abc123
            Return typedict
            ReturnsResponse Syntax{
              'interconnects': [
                {
                  'interconnectId': 'string',
                  'interconnectName': 'string',
                  'interconnectState': 'requested'|'pending'|'available'|'down'|'deleting'|'deleted',
                  'region': 'string',
                  'location': 'string',
                  'bandwidth': 'string',
                  'loaIssueTime': datetime(2015, 1, 1)
                },
              ]
            }
            Response Structure
            (dict) --A structure containing a list of interconnects.
            interconnects (list) --A list of interconnects.
            (dict) --An interconnect is a connection that can host other connections.
            Like a standard AWS Direct Connect connection, an interconnect represents the physical connection between an AWS Direct Connect partner's network and a specific Direct Connect location. An AWS Direct Connect partner who owns an interconnect can provision hosted connections on the interconnect for their end customers, thereby providing the end customers with connectivity to AWS services.
            The resources of the interconnect, including bandwidth and VLAN numbers, are shared by all of the hosted connections on the interconnect, and the owner of the interconnect determines how these resources are assigned.
            interconnectId (string) --The ID of the interconnect.
            Example: dxcon-abc123
            interconnectName (string) --The name of the interconnect.
            Example: '1G Interconnect to AWS '
            interconnectState (string) --State of the interconnect.
            Requested : The initial state of an interconnect. The interconnect stays in the requested state until the Letter of Authorization (LOA) is sent to the customer.
            Pending : The interconnect has been approved, and is being initialized.
            Available : The network link is up, and the interconnect is ready for use.
            Down : The network link is down.
            Deleting : The interconnect is in the process of being deleted.
            Deleted : The interconnect has been deleted.
            region (string) --The AWS region where the connection is located.
            Example: us-east-1
            Default: None
            location (string) --Where the connection is located.
            Example: EqSV5
            Default: None
            bandwidth (string) --Bandwidth of the connection.
            Example: 1Gbps
            Default: None
            loaIssueTime (datetime) --The time of the most recent call to DescribeInterconnectLoa for this Interconnect.
            
            
            
    :type interconnectId: string
    """
    pass

def describe_locations():
    """
    """
    pass

def describe_virtual_gateways():
    """
    """
    pass

def describe_virtual_interfaces(connectionId=None, virtualInterfaceId=None):
    """
    :param connectionId: ID of the connection.
            Example: dxcon-fg5678gh
            Default: None
            
    :type connectionId: string
    :param virtualInterfaceId: ID of the virtual interface.
            Example: dxvif-123dfg56
            Default: None
            
    :type virtualInterfaceId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def activate_gateway(ActivationKey=None, GatewayName=None, GatewayTimezone=None, GatewayRegion=None, GatewayType=None, TapeDriveType=None, MediumChangerType=None):
    """
    :param ActivationKey: [REQUIRED]
            Your gateway activation key. You can obtain the activation key by sending an HTTP GET request with redirects enabled to the gateway IP address (port 80). The redirect URL returned in the response provides you the activation key for your gateway in the query string parameter activationKey . It may also include other activation-related parameters, however, these are merely defaults -- the arguments you pass to the ActivateGateway API call determine the actual configuration of your gateway.
            
    :type ActivationKey: string
    :param GatewayName: [REQUIRED]
            The name you configured for your gateway.
            
    :type GatewayName: string
    :param GatewayTimezone: [REQUIRED]
            A value that indicates the time zone you want to set for the gateway. The time zone is used, for example, for scheduling snapshots and your gateway's maintenance schedule.
            
    :type GatewayTimezone: string
    :param GatewayRegion: [REQUIRED]
            A value that indicates the region where you want to store the snapshot backups. The gateway region specified must be the same region as the region in your Host header in the request. For more information about available regions and endpoints for AWS Storage Gateway, see Regions and Endpoints in the Amazon Web Services Glossary .
            Valid Values: 'us-east-1', 'us-west-1', 'us-west-2', 'eu-west-1', 'eu-central-1', 'ap-northeast-1', 'ap-northeast-2', 'ap-southeast-1', 'ap-southeast-2', 'sa-east-1'
            
    :type GatewayRegion: string
    :param GatewayType: A value that defines the type of gateway to activate. The type specified is critical to all later functions of the gateway and cannot be changed after activation. The default value is STORED .
    :type GatewayType: string
    :param TapeDriveType: The value that indicates the type of tape drive to use for gateway-VTL. This field is optional.
            Valid Values: 'IBM-ULT3580-TD5'
            
    :type TapeDriveType: string
    :param MediumChangerType: The value that indicates the type of medium changer to use for gateway-VTL. This field is optional.
            Valid Values: 'STK-L700', 'AWS-Gateway-VTL'
            
    :type MediumChangerType: string
    """
    pass

def add_cache(GatewayARN=None, DiskIds=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param DiskIds: [REQUIRED]
            (string) --
            
    :type DiskIds: list
    """
    pass

def add_tags_to_resource(ResourceARN=None, Tags=None):
    """
    :param ResourceARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the resource you want to add tags to.
            
    :type ResourceARN: string
    :param Tags: [REQUIRED]
            The key-value pair that represents the tag you want to add to the resource. The value can be an empty string.
            Note
            Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @.
            (dict) --
            Key (string) -- [REQUIRED]
            Value (string) -- [REQUIRED]
            
    :type Tags: list
    """
    pass

def add_upload_buffer(GatewayARN=None, DiskIds=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param DiskIds: [REQUIRED]
            (string) --
            
    :type DiskIds: list
    """
    pass

def add_working_storage(GatewayARN=None, DiskIds=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param DiskIds: [REQUIRED]
            An array of strings that identify disks that are to be configured as working storage. Each string have a minimum length of 1 and maximum length of 300. You can get the disk IDs from the ListLocalDisks API.
            (string) --
            
    :type DiskIds: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def cancel_archival(GatewayARN=None, TapeARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape you want to cancel archiving for.
            
    :type TapeARN: string
    """
    pass

def cancel_retrieval(GatewayARN=None, TapeARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape you want to cancel retrieval for.
            
    :type TapeARN: string
    """
    pass

def create_cached_iscsi_volume(GatewayARN=None, VolumeSizeInBytes=None, SnapshotId=None, TargetName=None, NetworkInterfaceId=None, ClientToken=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param VolumeSizeInBytes: [REQUIRED]
    :type VolumeSizeInBytes: integer
    :param SnapshotId: 
    :type SnapshotId: string
    :param TargetName: [REQUIRED]
    :type TargetName: string
    :param NetworkInterfaceId: [REQUIRED]
    :type NetworkInterfaceId: string
    :param ClientToken: [REQUIRED]
    :type ClientToken: string
    """
    pass

def create_snapshot(VolumeARN=None, SnapshotDescription=None):
    """
    :param VolumeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
            
    :type VolumeARN: string
    :param SnapshotDescription: [REQUIRED]
            Textual description of the snapshot that appears in the Amazon EC2 console, Elastic Block Store snapshots panel in the Description field, and in the AWS Storage Gateway snapshot Details pane, Description field
            
    :type SnapshotDescription: string
    """
    pass

def create_snapshot_from_volume_recovery_point(VolumeARN=None, SnapshotDescription=None):
    """
    :param VolumeARN: [REQUIRED]
    :type VolumeARN: string
    :param SnapshotDescription: [REQUIRED]
    :type SnapshotDescription: string
    """
    pass

def create_stored_iscsi_volume(GatewayARN=None, DiskId=None, SnapshotId=None, PreserveExistingData=None, TargetName=None, NetworkInterfaceId=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param DiskId: [REQUIRED]
            The unique identifier for the gateway local disk that is configured as a stored volume. Use ListLocalDisks to list disk IDs for a gateway.
            
    :type DiskId: string
    :param SnapshotId: The snapshot ID (e.g. 'snap-1122aabb') of the snapshot to restore as the new stored volume. Specify this field if you want to create the iSCSI storage volume from a snapshot otherwise do not include this field. To list snapshots for your account use DescribeSnapshots in the Amazon Elastic Compute Cloud API Reference .
    :type SnapshotId: string
    :param PreserveExistingData: [REQUIRED]
            Specify this field as true if you want to preserve the data on the local disk. Otherwise, specifying this field as false creates an empty volume.
            Valid Values: true, false
            
    :type PreserveExistingData: boolean
    :param TargetName: [REQUIRED]
            The name of the iSCSI target used by initiators to connect to the target and as a suffix for the target ARN. For example, specifying TargetName as myvolume results in the target ARN of arn:aws:storagegateway:us-east-1:111122223333:gateway/sgw-12A3456B/target/iqn.1997-05.com.amazon:myvolume. The target name must be unique across all volumes of a gateway.
            
    :type TargetName: string
    :param NetworkInterfaceId: [REQUIRED]
            The network interface of the gateway on which to expose the iSCSI target. Only IPv4 addresses are accepted. Use DescribeGatewayInformation to get a list of the network interfaces available on a gateway.
            Valid Values: A valid IP address.
            
    :type NetworkInterfaceId: string
    """
    pass

def create_tape_with_barcode(GatewayARN=None, TapeSizeInBytes=None, TapeBarcode=None):
    """
    :param GatewayARN: [REQUIRED]
            The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tape with. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeSizeInBytes: [REQUIRED]
            The size, in bytes, of the virtual tape that you want to create.
            Note
            The size must be aligned by gigabyte (1024*1024*1024 byte).
            
    :type TapeSizeInBytes: integer
    :param TapeBarcode: [REQUIRED]
            The barcode that you want to assign to the tape.
            
    :type TapeBarcode: string
    """
    pass

def create_tapes(GatewayARN=None, TapeSizeInBytes=None, ClientToken=None, NumTapesToCreate=None, TapeBarcodePrefix=None):
    """
    :param GatewayARN: [REQUIRED]
            The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tapes with. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeSizeInBytes: [REQUIRED]
            The size, in bytes, of the virtual tapes that you want to create.
            Note
            The size must be aligned by gigabyte (1024*1024*1024 byte).
            
    :type TapeSizeInBytes: integer
    :param ClientToken: [REQUIRED]
            A unique identifier that you use to retry a request. If you retry a request, use the same ClientToken you specified in the initial request.
            Note
            Using the same ClientToken prevents creating the tape multiple times.
            
    :type ClientToken: string
    :param NumTapesToCreate: [REQUIRED]
            The number of virtual tapes that you want to create.
            
    :type NumTapesToCreate: integer
    :param TapeBarcodePrefix: [REQUIRED]
            A prefix that you append to the barcode of the virtual tape you are creating. This prefix makes the barcode unique.
            Note
            The prefix must be 1 to 4 characters in length and must be one of the uppercase letters from A to Z.
            
    :type TapeBarcodePrefix: string
    """
    pass

def delete_bandwidth_rate_limit(GatewayARN=None, BandwidthType=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param BandwidthType: [REQUIRED]
    :type BandwidthType: string
    """
    pass

def delete_chap_credentials(TargetARN=None, InitiatorName=None):
    """
    :param TargetARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return to retrieve the TargetARN for specified VolumeARN.
            
    :type TargetARN: string
    :param InitiatorName: [REQUIRED]
            The iSCSI initiator that connects to the target.
            
    :type InitiatorName: string
    """
    pass

def delete_gateway(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the id of the deleted gateway.
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
            
    :type GatewayARN: string
    """
    pass

def delete_snapshot_schedule(VolumeARN=None):
    """
    :param VolumeARN: [REQUIRED]
            Return typedict
            ReturnsResponse Syntax{
              'VolumeARN': 'string'
            }
            Response Structure
            (dict) --
            VolumeARN (string) --
            
            
    :type VolumeARN: string
    """
    pass

def delete_tape(GatewayARN=None, TapeARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The unique Amazon Resource Name (ARN) of the gateway that the virtual tape to delete is associated with. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape to delete.
            
    :type TapeARN: string
    """
    pass

def delete_tape_archive(TapeARN=None):
    """
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape to delete from the virtual tape shelf (VTS).
            Return typedict
            ReturnsResponse Syntax{
              'TapeARN': 'string'
            }
            Response Structure
            (dict) --DeleteTapeArchiveOutput
            TapeARN (string) --The Amazon Resource Name (ARN) of the virtual tape that was deleted from the virtual tape shelf (VTS).
            
            
    :type TapeARN: string
    """
    pass

def delete_volume(VolumeARN=None):
    """
    :param VolumeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
            Return typedict
            ReturnsResponse Syntax{
              'VolumeARN': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the of the storage volume that was deleted
            VolumeARN (string) --The Amazon Resource Name (ARN) of the storage volume that was deleted. It is the same ARN you provided in the request.
            
            
    :type VolumeARN: string
    """
    pass

def describe_bandwidth_rate_limit(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'AverageUploadRateLimitInBitsPerSec': 123,
              'AverageDownloadRateLimitInBitsPerSec': 123
            }
            Response Structure
            (dict) --A JSON object containing the following fields:
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            AverageUploadRateLimitInBitsPerSec (integer) --The average upload bandwidth rate limit in bits per second. This field does not appear in the response if the upload rate limit is not set.
            AverageDownloadRateLimitInBitsPerSec (integer) --The average download bandwidth rate limit in bits per second. This field does not appear in the response if the download rate limit is not set.
            
            
    :type GatewayARN: string
    """
    pass

def describe_cache(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'DiskIds': [
                'string',
              ],
              'CacheAllocatedInBytes': 123,
              'CacheUsedPercentage': 123.0,
              'CacheDirtyPercentage': 123.0,
              'CacheHitPercentage': 123.0,
              'CacheMissPercentage': 123.0
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            DiskIds (list) --
            (string) --
            CacheAllocatedInBytes (integer) --
            CacheUsedPercentage (float) --
            CacheDirtyPercentage (float) --
            CacheHitPercentage (float) --
            CacheMissPercentage (float) --
            
            
    :type GatewayARN: string
    """
    pass

def describe_cached_iscsi_volumes(VolumeARNs=None):
    """
    :param VolumeARNs: [REQUIRED]
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'CachediSCSIVolumes': [
                {
                  'VolumeARN': 'string',
                  'VolumeId': 'string',
                  'VolumeType': 'string',
                  'VolumeStatus': 'string',
                  'VolumeSizeInBytes': 123,
                  'VolumeProgress': 123.0,
                  'SourceSnapshotId': 'string',
                  'VolumeiSCSIAttributes': {
                    'TargetARN': 'string',
                    'NetworkInterfaceId': 'string',
                    'NetworkInterfacePort': 123,
                    'LunNumber': 123,
                    'ChapEnabled': True|False
                  }
                },
              ]
            }
            Response Structure
            (dict) --A JSON object containing the following fields:
            CachediSCSIVolumes (list) --An array of objects where each object contains metadata about one cached volume.
            (dict) --
            VolumeARN (string) --
            VolumeId (string) --
            VolumeType (string) --
            VolumeStatus (string) --
            VolumeSizeInBytes (integer) --
            VolumeProgress (float) --
            SourceSnapshotId (string) --
            VolumeiSCSIAttributes (dict) --Lists iSCSI information about a volume.
            TargetARN (string) --The Amazon Resource Name (ARN) of the volume target.
            NetworkInterfaceId (string) --The network interface identifier.
            NetworkInterfacePort (integer) --The port used to communicate with iSCSI targets.
            LunNumber (integer) --The logical disk number.
            ChapEnabled (boolean) --Indicates whether mutual CHAP is enabled for the iSCSI target.
            
            
            
            
    :type VolumeARNs: list
    """
    pass

def describe_chap_credentials(TargetARN=None):
    """
    :param TargetARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return to retrieve the TargetARN for specified VolumeARN.
            Return typedict
            ReturnsResponse Syntax{
              'ChapCredentials': [
                {
                  'TargetARN': 'string',
                  'SecretToAuthenticateInitiator': 'string',
                  'InitiatorName': 'string',
                  'SecretToAuthenticateTarget': 'string'
                },
              ]
            }
            Response Structure
            (dict) --A JSON object containing a .
            ChapCredentials (list) --An array of ChapInfo objects that represent CHAP credentials. Each object in the array contains CHAP credential information for one target-initiator pair. If no CHAP credentials are set, an empty array is returned. CHAP credential information is provided in a JSON object with the following fields:
            InitiatorName : The iSCSI initiator that connects to the target.
            SecretToAuthenticateInitiator : The secret key that the initiator (for example, the Windows client) must provide to participate in mutual CHAP with the target.
            SecretToAuthenticateTarget : The secret key that the target must provide to participate in mutual CHAP with the initiator (e.g. Windows client).
            TargetARN : The Amazon Resource Name (ARN) of the storage volume.
            (dict) --Describes Challenge-Handshake Authentication Protocol (CHAP) information that supports authentication between your gateway and iSCSI initiators.
            TargetARN (string) --The Amazon Resource Name (ARN) of the volume.
            Valid Values: 50 to 500 lowercase letters, numbers, periods (.), and hyphens (-).
            SecretToAuthenticateInitiator (string) --The secret key that the initiator (for example, the Windows client) must provide to participate in mutual CHAP with the target.
            InitiatorName (string) --The iSCSI initiator that connects to the target.
            SecretToAuthenticateTarget (string) --The secret key that the target must provide to participate in mutual CHAP with the initiator (e.g. Windows client).
            
            
            
    :type TargetARN: string
    """
    pass

def describe_gateway_information(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'GatewayId': 'string',
              'GatewayName': 'string',
              'GatewayTimezone': 'string',
              'GatewayState': 'string',
              'GatewayNetworkInterfaces': [
                {
                  'Ipv4Address': 'string',
                  'MacAddress': 'string',
                  'Ipv6Address': 'string'
                },
              ],
              'GatewayType': 'string',
              'NextUpdateAvailabilityDate': 'string',
              'LastSoftwareUpdate': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the following fields:
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            GatewayId (string) --The unique identifier assigned to your gateway during activation. This ID becomes part of the gateway Amazon Resource Name (ARN), which you use as input for other operations.
            GatewayName (string) --The name you configured for your gateway.
            GatewayTimezone (string) --A value that indicates the time zone configured for the gateway.
            GatewayState (string) --A value that indicates the operating state of the gateway.
            GatewayNetworkInterfaces (list) --A NetworkInterface array that contains descriptions of the gateway network interfaces.
            (dict) --Describes a gateway's network interface.
            Ipv4Address (string) --The Internet Protocol version 4 (IPv4) address of the interface.
            MacAddress (string) --The Media Access Control (MAC) address of the interface.
            Note
            This is currently unsupported and will not be returned in output.
            Ipv6Address (string) --The Internet Protocol version 6 (IPv6) address of the interface. Currently not supported .
            
            GatewayType (string) --The type of the gateway.
            NextUpdateAvailabilityDate (string) --The date on which an update to the gateway is available. This date is in the time zone of the gateway. If the gateway is not available for an update this field is not returned in the response.
            LastSoftwareUpdate (string) --The date on which the last software update was applied to the gateway. If the gateway has never been updated, this field does not return a value in the response.
            
            
    :type GatewayARN: string
    """
    pass

def describe_maintenance_start_time(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'HourOfDay': 123,
              'MinuteOfHour': 123,
              'DayOfWeek': 123,
              'Timezone': 'string'
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            HourOfDay (integer) --
            MinuteOfHour (integer) --
            DayOfWeek (integer) --
            Timezone (string) --
            
            
    :type GatewayARN: string
    """
    pass

def describe_snapshot_schedule(VolumeARN=None):
    """
    :param VolumeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
            Return typedict
            ReturnsResponse Syntax{
              'VolumeARN': 'string',
              'StartAt': 123,
              'RecurrenceInHours': 123,
              'Description': 'string',
              'Timezone': 'string'
            }
            Response Structure
            (dict) --
            VolumeARN (string) --
            StartAt (integer) --
            RecurrenceInHours (integer) --
            Description (string) --
            Timezone (string) --
            
            
    :type VolumeARN: string
    """
    pass

def describe_stored_iscsi_volumes(VolumeARNs=None):
    """
    :param VolumeARNs: [REQUIRED]
            An array of strings where each string represents the Amazon Resource Name (ARN) of a stored volume. All of the specified stored volumes must from the same gateway. Use ListVolumes to get volume ARNs for a gateway.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'StorediSCSIVolumes': [
                {
                  'VolumeARN': 'string',
                  'VolumeId': 'string',
                  'VolumeType': 'string',
                  'VolumeStatus': 'string',
                  'VolumeSizeInBytes': 123,
                  'VolumeProgress': 123.0,
                  'VolumeDiskId': 'string',
                  'SourceSnapshotId': 'string',
                  'PreservedExistingData': True|False,
                  'VolumeiSCSIAttributes': {
                    'TargetARN': 'string',
                    'NetworkInterfaceId': 'string',
                    'NetworkInterfacePort': 123,
                    'LunNumber': 123,
                    'ChapEnabled': True|False
                  }
                },
              ]
            }
            Response Structure
            (dict) --
            StorediSCSIVolumes (list) --
            (dict) --
            VolumeARN (string) --
            VolumeId (string) --
            VolumeType (string) --
            VolumeStatus (string) --
            VolumeSizeInBytes (integer) --
            VolumeProgress (float) --
            VolumeDiskId (string) --
            SourceSnapshotId (string) --
            PreservedExistingData (boolean) --
            VolumeiSCSIAttributes (dict) --Lists iSCSI information about a volume.
            TargetARN (string) --The Amazon Resource Name (ARN) of the volume target.
            NetworkInterfaceId (string) --The network interface identifier.
            NetworkInterfacePort (integer) --The port used to communicate with iSCSI targets.
            LunNumber (integer) --The logical disk number.
            ChapEnabled (boolean) --Indicates whether mutual CHAP is enabled for the iSCSI target.
            
            
            
            
    :type VolumeARNs: list
    """
    pass

def describe_tape_archives(TapeARNs=None, Marker=None, Limit=None):
    """
    :param TapeARNs: Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe.
            (string) --
            
    :type TapeARNs: list
    :param Marker: An opaque string that indicates the position at which to begin describing virtual tapes.
    :type Marker: string
    :param Limit: Specifies that the number of virtual tapes descried be limited to the specified number.
    :type Limit: integer
    """
    pass

def describe_tape_recovery_points(GatewayARN=None, Marker=None, Limit=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param Marker: An opaque string that indicates the position at which to begin describing the virtual tape recovery points.
    :type Marker: string
    :param Limit: Specifies that the number of virtual tape recovery points that are described be limited to the specified number.
    :type Limit: integer
    """
    pass

def describe_tapes(GatewayARN=None, TapeARNs=None, Marker=None, Limit=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param TapeARNs: Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe. If this parameter is not specified, AWS Storage Gateway returns a description of all virtual tapes associated with the specified gateway.
            (string) --
            
    :type TapeARNs: list
    :param Marker: A marker value, obtained in a previous call to DescribeTapes . This marker indicates which page of results to retrieve.
            If not specified, the first page of results is retrieved.
            
    :type Marker: string
    :param Limit: Specifies that the number of virtual tapes described be limited to the specified number.
            Note
            Amazon Web Services may impose its own limit, if this field is not set.
            
    :type Limit: integer
    """
    pass

def describe_upload_buffer(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'DiskIds': [
                'string',
              ],
              'UploadBufferUsedInBytes': 123,
              'UploadBufferAllocatedInBytes': 123
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            DiskIds (list) --
            (string) --
            UploadBufferUsedInBytes (integer) --
            UploadBufferAllocatedInBytes (integer) --
            
            
    :type GatewayARN: string
    """
    pass

def describe_vtl_devices(GatewayARN=None, VTLDeviceARNs=None, Marker=None, Limit=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param VTLDeviceARNs: An array of strings, where each string represents the Amazon Resource Name (ARN) of a VTL device.
            Note
            All of the specified VTL devices must be from the same gateway. If no VTL devices are specified, the result will contain all devices on the specified gateway.
            (string) --
            
    :type VTLDeviceARNs: list
    :param Marker: An opaque string that indicates the position at which to begin describing the VTL devices.
    :type Marker: string
    :param Limit: Specifies that the number of VTL devices described be limited to the specified number.
    :type Limit: integer
    """
    pass

def describe_working_storage(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'DiskIds': [
                'string',
              ],
              'WorkingStorageUsedInBytes': 123,
              'WorkingStorageAllocatedInBytes': 123
            }
            Response Structure
            (dict) --A JSON object containing the following fields:
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            DiskIds (list) --An array of the gateway's local disk IDs that are configured as working storage. Each local disk ID is specified as a string (minimum length of 1 and maximum length of 300). If no local disks are configured as working storage, then the DiskIds array is empty.
            (string) --
            WorkingStorageUsedInBytes (integer) --The total working storage in bytes in use by the gateway. If no working storage is configured for the gateway, this field returns 0.
            WorkingStorageAllocatedInBytes (integer) --The total working storage in bytes allocated for the gateway. If no working storage is configured for the gateway, this field returns 0.
            
            
    :type GatewayARN: string
    """
    pass

def disable_gateway(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --DisableGatewayOutput
            GatewayARN (string) --The unique Amazon Resource Name of the disabled gateway.
            
            
    :type GatewayARN: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_gateways(Marker=None, Limit=None):
    """
    :param Marker: An opaque string that indicates the position at which to begin the returned list of gateways.
    :type Marker: string
    :param Limit: Specifies that the list of gateways returned be limited to the specified number of items.
    :type Limit: integer
    """
    pass

def list_local_disks(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'Disks': [
                {
                  'DiskId': 'string',
                  'DiskPath': 'string',
                  'DiskNode': 'string',
                  'DiskStatus': 'string',
                  'DiskSizeInBytes': 123,
                  'DiskAllocationType': 'string',
                  'DiskAllocationResource': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Disks (list) --
            (dict) --
            DiskId (string) --
            DiskPath (string) --
            DiskNode (string) --
            DiskStatus (string) --
            DiskSizeInBytes (integer) --
            DiskAllocationType (string) --
            DiskAllocationResource (string) --
            
            
            
    :type GatewayARN: string
    """
    pass

def list_tags_for_resource(ResourceARN=None, Marker=None, Limit=None):
    """
    :param ResourceARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the resource for which you want to list tags.
            
    :type ResourceARN: string
    :param Marker: An opaque string that indicates the position at which to begin returning the list of tags.
    :type Marker: string
    :param Limit: Specifies that the list of tags returned be limited to the specified number of items.
    :type Limit: integer
    """
    pass

def list_tapes(TapeARNs=None, Marker=None, Limit=None):
    """
    :param TapeARNs: The Amazon Resource Name (ARN) of each of the tapes you want to list. If you don't specify a tape ARN, the response lists all tapes in both your VTL and VTS.
            (string) --
            
    :type TapeARNs: list
    :param Marker: A string that indicates the position at which to begin the returned list of tapes.
    :type Marker: string
    :param Limit: An optional number limit for the tapes in the list returned by this call.
    :type Limit: integer
    """
    pass

def list_volume_initiators(VolumeARN=None):
    """
    :param VolumeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes for the gateway.
            Return typedict
            ReturnsResponse Syntax{
              'Initiators': [
                'string',
              ]
            }
            Response Structure
            (dict) --ListVolumeInitiatorsOutput
            Initiators (list) --The host names and port numbers of all iSCSI initiators that are connected to the gateway.
            (string) --
            
            
    :type VolumeARN: string
    """
    pass

def list_volume_recovery_points(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string',
              'VolumeRecoveryPointInfos': [
                {
                  'VolumeARN': 'string',
                  'VolumeSizeInBytes': 123,
                  'VolumeUsageInBytes': 123,
                  'VolumeRecoveryPointTime': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            VolumeRecoveryPointInfos (list) --
            (dict) --
            VolumeARN (string) --
            VolumeSizeInBytes (integer) --
            VolumeUsageInBytes (integer) --
            VolumeRecoveryPointTime (string) --
            
            
            
    :type GatewayARN: string
    """
    pass

def list_volumes(GatewayARN=None, Marker=None, Limit=None):
    """
    :param GatewayARN: The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
    :type GatewayARN: string
    :param Marker: A string that indicates the position at which to begin the returned list of volumes. Obtain the marker from the response of a previous List iSCSI Volumes request.
    :type Marker: string
    :param Limit: Specifies that the list of volumes returned be limited to the specified number of items.
    :type Limit: integer
    """
    pass

def remove_tags_from_resource(ResourceARN=None, TagKeys=None):
    """
    :param ResourceARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the resource you want to remove the tags from.
            
    :type ResourceARN: string
    :param TagKeys: [REQUIRED]
            The keys of the tags you want to remove from the specified resource. A tag is composed of a key/value pair.
            (string) --
            
    :type TagKeys: list
    """
    pass

def reset_cache(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
            
    :type GatewayARN: string
    """
    pass

def retrieve_tape_archive(TapeARN=None, GatewayARN=None):
    """
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape you want to retrieve from the virtual tape shelf (VTS).
            
    :type TapeARN: string
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway you want to retrieve the virtual tape to. Use the ListGateways operation to return a list of gateways for your account and region.
            You retrieve archived virtual tapes to only one gateway and the gateway must be a gateway-VTL.
            
    :type GatewayARN: string
    """
    pass

def retrieve_tape_recovery_point(TapeARN=None, GatewayARN=None):
    """
    :param TapeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the virtual tape for which you want to retrieve the recovery point.
            
    :type TapeARN: string
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    """
    pass

def set_local_console_password(GatewayARN=None, LocalConsolePassword=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param LocalConsolePassword: [REQUIRED]
            The password you want to set for your VM local console.
            
    :type LocalConsolePassword: string
    """
    pass

def shutdown_gateway(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the of the gateway that was shut down.
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
            
    :type GatewayARN: string
    """
    pass

def start_gateway(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the of the gateway that was restarted.
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
            
    :type GatewayARN: string
    """
    pass

def update_bandwidth_rate_limit(GatewayARN=None, AverageUploadRateLimitInBitsPerSec=None, AverageDownloadRateLimitInBitsPerSec=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param AverageUploadRateLimitInBitsPerSec: The average upload bandwidth rate limit in bits per second.
    :type AverageUploadRateLimitInBitsPerSec: integer
    :param AverageDownloadRateLimitInBitsPerSec: The average download bandwidth rate limit in bits per second.
    :type AverageDownloadRateLimitInBitsPerSec: integer
    """
    pass

def update_chap_credentials(TargetARN=None, SecretToAuthenticateInitiator=None, InitiatorName=None, SecretToAuthenticateTarget=None):
    """
    :param TargetARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return the TargetARN for specified VolumeARN.
            
    :type TargetARN: string
    :param SecretToAuthenticateInitiator: [REQUIRED]
            The secret key that the initiator (for example, the Windows client) must provide to participate in mutual CHAP with the target.
            Note
            The secret key must be between 12 and 16 bytes when encoded in UTF-8.
            
    :type SecretToAuthenticateInitiator: string
    :param InitiatorName: [REQUIRED]
            The iSCSI initiator that connects to the target.
            
    :type InitiatorName: string
    :param SecretToAuthenticateTarget: The secret key that the target must provide to participate in mutual CHAP with the initiator (e.g. Windows client).
            Byte constraints: Minimum bytes of 12. Maximum bytes of 16.
            Note
            The secret key must be between 12 and 16 bytes when encoded in UTF-8.
            
    :type SecretToAuthenticateTarget: string
    """
    pass

def update_gateway_information(GatewayARN=None, GatewayName=None, GatewayTimezone=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param GatewayName: The name you configured for your gateway.
    :type GatewayName: string
    :param GatewayTimezone: 
    :type GatewayTimezone: string
    """
    pass

def update_gateway_software_now(GatewayARN=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            Return typedict
            ReturnsResponse Syntax{
              'GatewayARN': 'string'
            }
            Response Structure
            (dict) --A JSON object containing the of the gateway that was updated.
            GatewayARN (string) --The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
            
    :type GatewayARN: string
    """
    pass

def update_maintenance_start_time(GatewayARN=None, HourOfDay=None, MinuteOfHour=None, DayOfWeek=None):
    """
    :param GatewayARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and region.
            
    :type GatewayARN: string
    :param HourOfDay: [REQUIRED]
            The hour component of the maintenance start time represented as hh , where hh is the hour (00 to 23). The hour of the day is in the time zone of the gateway.
            
    :type HourOfDay: integer
    :param MinuteOfHour: [REQUIRED]
            The minute component of the maintenance start time represented as mm , where mm is the minute (00 to 59). The minute of the hour is in the time zone of the gateway.
            
    :type MinuteOfHour: integer
    :param DayOfWeek: [REQUIRED]
            The maintenance start time day of the week.
            
    :type DayOfWeek: integer
    """
    pass

def update_snapshot_schedule(VolumeARN=None, StartAt=None, RecurrenceInHours=None, Description=None):
    """
    :param VolumeARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
            
    :type VolumeARN: string
    :param StartAt: [REQUIRED]
            The hour of the day at which the snapshot schedule begins represented as hh , where hh is the hour (0 to 23). The hour of the day is in the time zone of the gateway.
            
    :type StartAt: integer
    :param RecurrenceInHours: [REQUIRED]
            Frequency of snapshots. Specify the number of hours between snapshots.
            
    :type RecurrenceInHours: integer
    :param Description: Optional description of the snapshot that overwrites the existing description.
    :type Description: string
    """
    pass

def update_vtl_device_type(VTLDeviceARN=None, DeviceType=None):
    """
    :param VTLDeviceARN: [REQUIRED]
            The Amazon Resource Name (ARN) of the medium changer you want to select.
            
    :type VTLDeviceARN: string
    :param DeviceType: [REQUIRED]
            The type of medium changer you want to select.
            Valid Values: 'STK-L700', 'AWS-Gateway-VTL'
            
    :type DeviceType: string
    """
    pass

